@@ -24,33 +24,68 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-dynamodbstreams-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.dynamodbstreamslambda`|
 
+## Overview
+
 This AWS Solutions Construct implements a pattern Amazon DynamoDB table with stream to invoke the AWS Lambda function  with the least privileged permissions.
 
-Here is a minimal deployable pattern definition in Typescript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { DynamoDBStreamsToLambdaProps,  DynamoDBStreamsToLambda} from '@aws-solutions-constructs/aws-dynamodbstreams-lambda';
+import * as lambda from 'aws-cdk-lib/aws-lambda';
 
 new DynamoDBStreamsToLambda(this, 'test-dynamodbstreams-lambda', {
   lambdaFunctionProps: {
-      code: lambda.Code.fromAsset(`${__dirname}/lambda`),
+      code: lambda.Code.fromAsset(`lambda`),
       runtime: lambda.Runtime.NODEJS_14_X,
       handler: 'index.handler'
   },
 });
 ```
 
-## Initializer
+Python
 
-```text
-new DynamoDBStreamsToLambda(scope: Construct, id: string, props: DynamoDBStreamsToLambdaProps);
+```python
+from aws_solutions_constructs.aws_dynamodbstreams_lambda import DynamoDBStreamsToLambda
+from aws_cdk import (
+  aws_lambda as _lambda,
+  Stack
+)
+from constructs import Construct
+
+DynamoDBStreamsToLambda(self, 'test-dynamodbstreams-lambda',
+                        lambda_function_props=_lambda.FunctionProps(
+                            code=_lambda.Code.from_asset('lambda'),
+                            runtime=_lambda.Runtime.PYTHON_3_9,
+                            handler='index.handler'
+                        )
+                        )
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`DynamoDBStreamsToLambdaProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awscdk.services.lambda.*;
+import software.amazon.awscdk.services.lambda.Runtime;
+import software.amazon.awsconstructs.services.dynamodbstreamslambda.*;
+
+new DynamoDBStreamsToLambda(this, "test-dynamodbstreams-lambda",
+        new DynamoDBStreamsToLambdaProps.Builder()
+                .lambdaFunctionProps(new FunctionProps.Builder()
+                        .runtime(Runtime.NODEJS_14_X)
+                        .code(Code.fromAsset("lambda"))
+                        .handler("index.handler")
+                        .build())
+                .build());
+```
 
 ## Pattern Construct Props
 
@@ -103,7 +138,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -115,6 +150,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb
@@ -135,11 +172,11 @@ class DynamoDBStreamsToLambda(
         *,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         dynamo_event_source_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -155,6 +192,10 @@ class DynamoDBStreamsToLambda(
         :access: public
         :summary: Constructs a new instance of the LambdaToDynamoDB class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DynamoDBStreamsToLambda.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DynamoDBStreamsToLambdaProps(
             deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
             dynamo_event_source_props=dynamo_event_source_props,
@@ -202,11 +243,11 @@ class DynamoDBStreamsToLambdaProps:
         *,
         deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         dynamo_event_source_props: typing.Any = None,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_interface: typing.Optional[aws_cdk.aws_dynamodb.ITable] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
-        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
+        sqs_dlq_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
@@ -225,6 +266,15 @@ class DynamoDBStreamsToLambdaProps:
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(sqs_dlq_queue_props, dict):
             sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(DynamoDBStreamsToLambdaProps.__init__)
+            check_type(argname="argument deploy_sqs_dlq_queue", value=deploy_sqs_dlq_queue, expected_type=type_hints["deploy_sqs_dlq_queue"])
+            check_type(argname="argument dynamo_event_source_props", value=dynamo_event_source_props, expected_type=type_hints["dynamo_event_source_props"])
+            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_table_interface", value=existing_table_interface, expected_type=type_hints["existing_table_interface"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument sqs_dlq_queue_props", value=sqs_dlq_queue_props, expected_type=type_hints["sqs_dlq_queue_props"])
         self._values: typing.Dict[str, typing.Any] = {}
         if deploy_sqs_dlq_queue is not None:
             self._values["deploy_sqs_dlq_queue"] = deploy_sqs_dlq_queue
